MatrixCoefficients

Enum MatrixCoefficients 

pub enum MatrixCoefficients {
Show 15 variants Identity, ItuRBt709, Unspecified, Reserved1, UsFcc73682, ItuRBt470Bg, Smpte170M, Smpte240M, YCoCg, Bt2020NonConstantLuminance, Bt2020ConstantLuminance, SmpteSt2085, ChromaDerivedNonConstantLuminance, ChromaDerivedConstantLuminance, ItuRBt21000,
}
The Matrix Coefficients of the video used to derive luma and chroma values from red, green, and blue color primaries. For clarity, the value and meanings for MatrixCoefficients are adopted from Table 4 of ISO/IEC 23001-8:2016 or ITU-T H.273.

Variants



Identity

Identity



ItuRBt709

ITU-R BT.709



Unspecified

unspecified



Reserved1

reserved



UsFcc73682

US FCC 73.682



ItuRBt470Bg

ITU-R BT.470BG



Smpte170M

SMPTE 170M



Smpte240M

SMPTE 240M



YCoCg

YCoCg



Bt2020NonConstantLuminance

BT2020 Non-constant Luminance



Bt2020ConstantLuminance

BT2020 Constant Luminance



SmpteSt2085

SMPTE ST 2085



ChromaDerivedNonConstantLuminance

Chroma-derived Non-constant Luminance



ChromaDerivedConstantLuminance

Chroma-derived Constant Luminance



ItuRBt21000

ITU-R BT.2100-0

Implementations

Source

impl MatrixCoefficients

pub fn new(value: u64) -> Option<Self>

Create a new instance